==> camel-k-crds-2.2.0-sources.jar: org/apache/camel/v1/camelcatalogspec/loaders/DependenciesFluent.java <==
package org.apache.camel.v1.camelcatalogspec.loaders;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DependenciesFluent<A extends DependenciesFluent<A>> extends BaseFluent<A>{
  public DependenciesFluent() {
  }
  
  public DependenciesFluent(Dependencies instance) {
    this.copyInstance(instance);
  }
  private String artifactId;
  private String groupId;
  private String version;
  
  protected void copyInstance(Dependencies instance) {
    instance = (instance != null ? instance : new Dependencies());
    if (instance != null) {
          this.withArtifactId(instance.getArtifactId());
          this.withGroupId(instance.getGroupId());
          this.withVersion(instance.getVersion());
        }
  }
  
  public String getArtifactId() {
    return this.artifactId;
  }
  
  public A withArtifactId(String artifactId) {
    this.artifactId = artifactId;
    return (A) this;
  }
  
  public boolean hasArtifactId() {
    return this.artifactId != null;
  }
  
  public String getGroupId() {
    return this.groupId;
  }
  
  public A withGroupId(String groupId) {
    this.groupId = groupId;
    return (A) this;
  }
  
  public boolean hasGroupId() {
    return this.groupId != null;
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version = version;
    return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DependenciesFluent that = (DependenciesFluent) o;
    if (!java.util.Objects.equals(artifactId, that.artifactId)) return false;
    if (!java.util.Objects.equals(groupId, that.groupId)) return false;
    if (!java.util.Objects.equals(version, that.version)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(artifactId,  groupId,  version,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (artifactId != null) { sb.append("artifactId:"); sb.append(artifactId + ","); }
    if (groupId != null) { sb.append("groupId:"); sb.append(groupId + ","); }
    if (version != null) { sb.append("version:"); sb.append(version); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> camel-k-crds-2.4.0-sources.jar: org/apache/camel/v1/camelcatalogspec/loaders/DependenciesFluent.java <==
package org.apache.camel.v1.camelcatalogspec.loaders;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DependenciesFluent<A extends DependenciesFluent<A>> extends BaseFluent<A>{
  public DependenciesFluent() {
  }
  
  public DependenciesFluent(Dependencies instance) {
    this.copyInstance(instance);
  }
  private String artifactId;
  private String classifier;
  private String groupId;
  private String type;
  private String version;
  
  protected void copyInstance(Dependencies instance) {
    instance = (instance != null ? instance : new Dependencies());
    if (instance != null) {
          this.withArtifactId(instance.getArtifactId());
          this.withClassifier(instance.getClassifier());
          this.withGroupId(instance.getGroupId());
          this.withType(instance.getType());
          this.withVersion(instance.getVersion());
        }
  }
  
  public String getArtifactId() {
    return this.artifactId;
  }
  
  public A withArtifactId(String artifactId) {
    this.artifactId = artifactId;
    return (A) this;
  }
  
  public boolean hasArtifactId() {
    return this.artifactId != null;
  }
  
  public String getClassifier() {
    return this.classifier;
  }
  
  public A withClassifier(String classifier) {
    this.classifier = classifier;
    return (A) this;
  }
  
  public boolean hasClassifier() {
    return this.classifier != null;
  }
  
  public String getGroupId() {
    return this.groupId;
  }
  
  public A withGroupId(String groupId) {
    this.groupId = groupId;
    return (A) this;
  }
  
  public boolean hasGroupId() {
    return this.groupId != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public String getVersion() {
    return this.version;
  }
  
  public A withVersion(String version) {
    this.version = version;
    return (A) this;
  }
  
  public boolean hasVersion() {
    return this.version != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DependenciesFluent that = (DependenciesFluent) o;
    if (!java.util.Objects.equals(artifactId, that.artifactId)) return false;
    if (!java.util.Objects.equals(classifier, that.classifier)) return false;
    if (!java.util.Objects.equals(groupId, that.groupId)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(version, that.version)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(artifactId,  classifier,  groupId,  type,  version,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (artifactId != null) { sb.append("artifactId:"); sb.append(artifactId + ","); }
    if (classifier != null) { sb.append("classifier:"); sb.append(classifier + ","); }
    if (groupId != null) { sb.append("groupId:"); sb.append(groupId + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (version != null) { sb.append("version:"); sb.append(version); }
    sb.append("}");
    return sb.toString();
  }
  

}
